ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind {
Show 14 variants Empty, TooLong, InvalidScheme, SchemeMissing, InvalidChar(char), InvalidPercentEncoding, InvalidAuthority, AuthorityMissing, InvalidHost, InvalidIpv4, InvalidIpv6, InvalidPort, PortOutOfRange, InvalidPath,
}
The reason a URL or URL component is invalid.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Empty

The input is empty.



TooLong

The URL is longer than 65535 bytes.



InvalidScheme

The scheme contains invalid characters.



SchemeMissing

The URL has no scheme, but the operation requires one.



InvalidChar(char)

The character is not allowed at this position.



InvalidPercentEncoding

A % is not followed by two hex digits.



InvalidAuthority

The authority is malformed.



AuthorityMissing

The URL has no authority, but the operation requires one.



InvalidHost

The host is malformed.



InvalidIpv4

The host looks like an IPv4 address but isn’t a valid one.



InvalidIpv6

The bracketed host isn’t a valid IPv6 address.



InvalidPort

The port contains non-digit characters.



PortOutOfRange

The port is greater than 65535.



InvalidPath

The path, file name or extension is malformed.