unquote

Function unquote 

pub fn unquote(src: &str, component: Component) -> Cow<'_, str>
Decodes a percent-encoded value.

For Component::QueryPart + is decoded as space. For Component::Query + is decoded as space too, but escapes of &, =, + and ; are kept, so the result can still be split into pairs.