Struct PathAndQuery Copy item path Source pub struct PathAndQuery();Expand description Path with an optional query: path ["?" query].
Returns the component as a string slice.
Strictly validates a path and query.
use urly::PathAndQuery;
let pq = PathAndQuery::new("/search?q=rust" ).unwrap();
assert_eq! (pq.path(), "/search" );
assert_eq! (pq.query().unwrap(), "q=rust" );Converts a static string to a path and query.
 Panics
Panics if the path or query is not valid.
Returns the query, if present.
Converts this type into a shared reference of the (usually inferred) input type.
Formats the value using the given formatter.
Read more Formats the value using the given formatter.
Read more This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more Converts the given value to a
String.
Read more